@@ -3,13 +3,13 @@
 
 static const char CAIXS_PKG_PREFIX[] = "__cag_";
 
-struct double_hek {
+typedef struct double_hek {
     U32  hek_hash;
     U32  pkg_hash;
     I32  hek_len;
-    char prefix[8]; /* fixed CAIXS_PKG_PREFIX string, shifted by 2 bytes offset to prevent padding */
-    char hek_key[1];
-};
+    char prefix[8];  /* fixed CAIXS_PKG_PREFIX string, shifted by 2 bytes offset to prevent padding */
+    char hek_key[4]; /* those bytes'll be eaten by padding, so force their allocation ourselves */
+} double_hek;
 
 #define HEK_PKG_LEN(hent) \
     (HEK_LEN(hent) + sizeof(CAIXS_PKG_PREFIX) - 1)
